public inbox for eclipse@sourceware.org
 help / color / mirror / Atom feed
From: Paul Nasrat <pauln@truemesh.com>
To: John Healy <jhealy@redhat.com>
Cc: "David A. Frantz" <wizard@eznet.net>, eclipse@sources.redhat.com
Subject: Re: eclipse in fedora core 2 test 1
Date: Tue, 17 Feb 2004 16:14:00 -0000	[thread overview]
Message-ID: <20040217160836.GN15070@lichen.truemesh.com> (raw)
In-Reply-To: <1077034146.1147.0.camel@to-dhcp5.toronto.redhat.com>

[-- Attachment #1: Type: text/plain, Size: 388 bytes --]

On Tue, Feb 17, 2004 at 11:09:06AM -0500, John Healy wrote:

> Eclipse will be made available for FC2 at some point in the near future
> but it won't be part of the core.  Stay tuned.

Intresting.

Could you give us an idea of which snapshot it would be.  Also the original snapshot will probably be buildable once ant pops out of rawhide with something like the attached I believe

Paul

[-- Attachment #2: eclipse-gcjlib-not-solib.patch --]
[-- Type: text/plain, Size: 4091 bytes --]

--- ./plugins/org.eclipse.core.boot/src/org/eclipse/core/internal/boot/InternalBootLoader.java.orig	2004-01-06 10:58:32.000000000 +0000
+++ ./plugins/org.eclipse.core.boot/src/org/eclipse/core/internal/boot/InternalBootLoader.java	2004-01-06 10:59:45.000000000 +0000
@@ -376,7 +376,7 @@
 	File soFile = new File(baseDir, System.mapLibraryName(baseName));
 	if (! soFile.exists())
 		return null;
-	return "solib:" + soFile;
+	return "gcjlib:" + soFile;
 }
 
 private static Object[] getPlatformClassLoaderPath() {
--- ./plugins/org.eclipse.core.runtime/src/org/eclipse/core/internal/plugins/PluginDescriptor.java.orig	2004-01-06 10:58:32.000000000 +0000
+++ ./plugins/org.eclipse.core.runtime/src/org/eclipse/core/internal/plugins/PluginDescriptor.java	2004-01-06 11:00:00.000000000 +0000
@@ -52,7 +52,7 @@
 
 	// If this class was loaded from a shared library, then try to
 	// load other plugins as shared objects.
-	private static final boolean canUseSolib = PluginDescriptor.class.getProtectionDomain().getCodeSource().getLocation().getProtocol().equals("solib");
+	private static final boolean canUseSolib = PluginDescriptor.class.getProtectionDomain().getCodeSource().getLocation().getProtocol().equals("gcjlib");
 
 	// Places to look for library files 
 	private static String[] WS_JAR_VARIANTS = buildWSVariants();
--- ./plugins/org.eclipse.jdt.core/Makefile.orig	2004-01-06 11:01:20.230845328 +0000
+++ ./plugins/org.eclipse.jdt.core/Makefile	2004-01-06 09:56:54.000000000 +0000
@@ -302,7 +302,7 @@
 	$(GCJ) -c $(XGCJFLAGS) --resource $(shell echo $< | sed -e 's,^[^/]*/,,') -o $@ $<
 
 $(LIBRARY): $(OBJECTS)
-	$(GCJ) -shared $(XGCJFLAGS) -o $(LIBRARY) $(OBJECTS) -l-org-apache-tools-1.5.2
+	$(GCJ) -shared $(XGCJFLAGS) -o $(LIBRARY) $(OBJECTS) -l-org-apache-tools-ant-1.5.2
 
 clean:
 	-rm -rf $(OBJECTS) $(LIBRARY)
--- ./plugins/org.eclipse.platform/src/org/eclipse/core/launcher/Main.java.orig	2004-01-06 10:58:32.000000000 +0000
+++ ./plugins/org.eclipse.platform/src/org/eclipse/core/launcher/Main.java	2004-01-06 11:00:23.000000000 +0000
@@ -397,10 +397,10 @@
 		url = null;
 		if ("file".equals(base.getProtocol())) {
 			URL	self = getClass().getProtectionDomain().getCodeSource().getLocation();
-			if (self.getProtocol().equals("solib")) {
+			if (self.getProtocol().equals("gcjlib")) {
 				File so = new File(base.getFile(), BOOTSO);
 				if (so.exists())
-					url = new URL("solib", "", so.toString());
+					url = new URL("gcjlib", "", so.toString());
 			}
 		}
 		if (url == null)
@@ -868,7 +868,7 @@
 	String path = decode(url.getFile());
 	path = new File(path).getAbsolutePath().replace(File.separatorChar,'/');
 	String protocol = url.getProtocol();
-	if (protocol.equals("solib")) {
+	if (protocol.equals("gcjlib")) {
 		path = path.substring(0, path.lastIndexOf("/")+1); //$NON-NLS-1$
 		protocol = "file";
 	} else if (path.endsWith(".jar")) //$NON-NLS-1$
--- ./gcjlauncher.java.orig	2004-01-06 10:58:32.000000000 +0000
+++ ./gcjlauncher.java	2004-01-06 10:58:56.000000000 +0000
@@ -75,7 +75,7 @@
 
 	String className = args[i++];
 
-	URL startupURL = new URL("solib", "", startup_so.toString());
+	URL startupURL = new URL("gcjlib", "", startup_so.toString());
 	URLClassLoader loader = new URLClassLoader(new URL[] { startupURL });
 
 	String[] rest = new String[args.length - i];

  reply	other threads:[~2004-02-17 16:14 UTC|newest]

Thread overview: 10+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2004-02-17  2:26 David A. Frantz
2004-02-17 16:09 ` John Healy
2004-02-17 16:14   ` Paul Nasrat [this message]
2004-02-17 16:57     ` John Healy
2004-02-17 17:09     ` Jeff Duska
2004-02-17 17:21       ` Jeremy Handcock
2004-02-17 18:38       ` Jeff Sturm
2004-02-17 20:22       ` Karen Bennet
2004-02-17 20:46     ` Tom Tromey
  -- strict thread matches above, loose matches on Subject: below --
2004-02-15 20:11 J. Scott Amort

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20040217160836.GN15070@lichen.truemesh.com \
    --to=pauln@truemesh.com \
    --cc=eclipse@sources.redhat.com \
    --cc=jhealy@redhat.com \
    --cc=wizard@eznet.net \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
--- ./plugins/org.eclipse.core.boot/src/org/eclipse/core/internal/boot/DelegatingURLClassLoader.java.orig	2004-01-06 10:58:32.000000000 +0000
+++ ./plugins/org.eclipse.core.boot/src/org/eclipse/core/internal/boot/DelegatingURLClassLoader.java	2004-01-06 10:59:35.000000000 +0000
@@ -41,7 +41,7 @@
 	// filter table
 	private Hashtable filterTable = new Hashtable();
 
 	// whether any URL is solib:
 	private boolean anySolibURL = false;
 
 	// development mode class path additions
@@ -271,7 +271,7 @@
 	resourcePath = mungeJarURLs(resourcePath);
 
 	for (int i = 0; i < codePath.length; ++i) {
-		if (codePath[i].getProtocol().equals("solib")) {
+		if (codePath[i].getProtocol().equals("gcjlib")) {
 			anySolibURL = true;
 			break;
 		}
@@ -41,7 +41,7 @@
 	private Hashtable filterTable = new Hashtable();
 
-	// whether any URL is solib:
+	// whether any URL is gcjlib:
 	private boolean anySolibURL = false;
 